@@ -1,5 +1,5 @@
 /*
- * $Id: avrcore.c,v 1.87 2008/03/16 21:14:07 joerg_wunsch Exp $
+ * $Id: avrcore.c,v 1.88 2008/03/19 22:39:01 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -378,6 +378,7 @@ avr_core_construct (AvrCore *core, DevSuppDefn *dev)
     int PC_sz = dev_supp_get_PC_sz (dev);
     int stack_sz = dev_supp_get_stack_sz (dev);
     int sram_sz = dev_supp_get_sram_sz (dev);
+    int eeprom_sz = dev_supp_get_eeprom_sz (dev);
     int xram_sz = dev_supp_get_xram_sz (dev);
     int vtab_idx = dev_supp_get_vtab_idx (dev);
     int xram_end, sram_end;
@@ -439,6 +440,17 @@ avr_core_construct (AvrCore *core, DevSuppDefn *dev)
                               (VDevice *)core->gpwr, 0, 0, 0xff, 0xff);
     }
 
+    /* Setup EEPROM before IO regs since its object is re-used in the EEPROM
+       control registers. */
+    if (eeprom_sz)
+    {
+	core->eeprom = eeprom_new (eeprom_sz, mask_EERE | mask_EEWE | mask_EEMWE);
+    }
+    else
+    {
+	core->eeprom = NULL;
+    }
+
     dev_supp_attach_io_regs (core, dev);
 
     /* Set up the stack. */
@@ -522,8 +534,6 @@ avr_core_construct (AvrCore *core, DevSuppDefn *dev)
         core->xram = NULL;
     }
 
-    core->eeprom = NULL;
-
     /* Initialize the decoder lookup table */
 
     decode_init_lookup_table ();
