@@ -1,5 +1,5 @@
 /*
- * $Id: mega128.h,v 1.3 2008/01/05 22:27:05 joerg_wunsch Exp $
+ * $Id: mega128.h,v 1.4 2008/03/19 22:39:03 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -182,6 +182,34 @@ static DevSuppDefn defn_atmega128 = {
             .rd_mask = 0xff,
             .wr_mask = 0xff,
         },
+        {
+	    .addr = 0x3c,
+	    .name = "EECR",
+	    .vdev_create = eeprom_create,
+	    .rd_mask = 0x0f,
+	    .wr_mask = 0x0f,
+	},
+        {
+	    .addr = 0x3d,
+	    .name = "EEDR",
+	    .ref_addr = 0x3c,
+	    .rd_mask = 0xff,
+	    .wr_mask = 0xff,
+	},
+        {
+	    .addr = 0x3e,
+	    .name = "EEARL",
+	    .ref_addr = 0x3c,
+	    .rd_mask = 0xff,
+	    .wr_mask = 0xff,
+	},
+        {
+	    .addr = 0x3f,
+	    .name = "EEARH",
+	    .ref_addr = 0x3c,
+	    .rd_mask = 0x0f,
+	    .wr_mask = 0x0f,
+	},
         { .addr = 0x40, .name = "SFIOR", },
         { .addr = 0x41, .name = "WDTCR", },
         { .addr = 0x42, .name = "OCDR", },
