@@ -1,5 +1,5 @@
 /*
- * $Id: eeprom.c,v 1.20 2004/01/30 07:09:56 troth Exp $
+ * $Id: eeprom.c,v 1.21 2008/03/19 22:39:02 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -66,15 +66,39 @@ static void eeprom_wr_eecr (EEProm *ee, uint8_t val);
 static int eeprom_wr_op_cb (uint64_t time, AvrClass *data);
 static int eeprom_mwe_clr_cb (uint64_t time, AvrClass *data);
 
+/* XXX */
+static VDevice *global_eeprom;
+
+/**
+ * \brief Create a new EEPROM control register set instance.
+ *
+ * This should only be used in DevSuppDefn initializers.
+ */
+
+VDevice *
+eeprom_create (int addr, char *name, int rel_addr, void *data)
+{
+    if (rel_addr == 0 && addr != EECR_ADDR)
+        avr_error("Attempt to create EEPROM control register at unknown address: 0x%02x != 0x%02x",
+		  addr, EECR_ADDR);
+
+    return global_eeprom;
+}
+
 EEProm *
 eeprom_new (int size, uint8_t eecr_mask)
 {
     EEProm *eeprom;
 
+    if (global_eeprom != NULL)
+        avr_error("Global EEPROM does already exist");
+
     eeprom = avr_new (EEProm, 1);
     eeprom_construct (eeprom, size, eecr_mask);
     class_overload_destroy ((AvrClass *)eeprom, eeprom_destroy);
 
+    global_eeprom = (VDevice *)eeprom;
+
     return eeprom;
 }
 
@@ -280,7 +304,7 @@ eeprom_wr_op_cb (uint64_t time, AvrClass *data)
 
     /* write the data in eedr into eeprom at addr */
     addr = (ee->eearh << 8) | ee->eearl;
-    avr_warning ("writing 0x%02x to eeprom at 0x%04x\n", ee->eedr, addr);
+    //avr_warning ("writing 0x%02x to eeprom at 0x%04x\n", ee->eedr, addr);
     display_eeprom (addr, 1, &ee->eedr);
     storage_writeb (ee->stor, addr, ee->eedr);
 
