@@ -1,5 +1,5 @@
 /*
- * $Id: memory.c,v 1.22 2008/01/06 22:38:19 joerg_wunsch Exp $
+ * $Id: memory.c,v 1.24 2009/02/24 21:10:12 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -180,6 +180,14 @@ mem_get_vdevice_by_name (Memory *mem, char *name)
 static MemoryCell *
 mem_get_cell (Memory *mem, int addr)
 {
+    /*
+     * Just return *any* possible cell for illegal addresses,
+     * to avoid accessing cells that have not been allocated.
+     * Later on, the illegal address will be caught anyway.
+     */
+    if ((addr < 0) || (addr > mem->xram_end))
+        addr = mem->xram_end - 1;
+
     return mem->cell + addr;
 }
 
@@ -361,24 +369,24 @@ mem_io_fetch (Memory *mem, int addr, uint8_t * val, char *buf, int bufsiz)
 static void
 mem_io_reg_dump_core (Memory *mem, FILE * f_core)
 {
-    int i, j;
+    unsigned int i, j;
     char name[80];
     uint8_t val;
 
-    int begin = mem->gpwr_end + 1;
-    int end = mem->io_reg_end;
-    int half = (end - begin) / 2;
-    int mid = begin + half;
+    unsigned int begin = (unsigned)mem->gpwr_end + 1;
+    unsigned int end = (unsigned)mem->io_reg_end;
+    unsigned int half = (end - begin + 1) / 2;
+    unsigned int mid = begin + half;
 
     fprintf (f_core, "IO Register Dump:\n");
     for (i = begin; i < mid; i++)
     {
-        for (j = i; j < end; j += half)
+        for (j = i; j <= end; j += half)
         {
             memset (name, '\0', sizeof (name));
             mem_io_fetch (mem, j, &val, name, sizeof (name) - 1);
 
-            fprintf (f_core, "%02x : %-10s : 0x%02x               ", j - half,
+            fprintf (f_core, "%02x : %-10s : 0x%02x               ", j,
                      name, val);
         }
         fprintf (f_core, "\n");
