@@ -1,5 +1,5 @@
 /*
- * $Id: vdevs.h,v 1.31 2004/01/30 07:09:56 troth Exp $
+ * $Id: vdevs.h,v 1.32 2009/02/24 19:54:33 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -70,7 +70,7 @@ extern void vdev_reset (VDevice *dev);
 
 extern void vdev_set_core (VDevice *dev, AvrClass *core);
 
-extern inline AvrClass *vdev_get_core (VDevice *dev)
+static inline AvrClass *vdev_get_core (VDevice *dev)
 {
     return dev->core;
 }
